//  Copyright (c) CNES  2008
//
//  This software is part of CelestLab, a CNES toolbox for Scilab
//
//  This software is governed by the CeCILL  license under French law and
//  abiding by the rules of distribution of free software.  You can  use,
//  modify and/ or redistribute the software under the terms of the CeCILL
//  license as circulated by CEA, CNRS and INRIA at the following URL
//  'http://www.cecill.info'.

function [sma,ecc] = CL_op_rpvinf2ae(rp,vinf,mu)
// Periapsis radius and velocity at infinity to semi major axis and eccentricity (hyperbolic orbits)
//
// Calling Sequence
// [sma,ecc] = CL_op_rpvinf2ae(rp,vinf[,mu])
//
// Description
// <itemizedlist><listitem>
// Computes keplerian parameters semi major axis and eccentricity from
// periapsis radius and velocity at infinity (only for hyperbolic orbits).
// </listitem>
// </itemizedlist>
// <para><emphasis role="bold">( Last updated: 2010-02-17 )</emphasis></para>
//
// Parameters
// rp: periapsis radius [m] (1xN)
// vind: velocity at infinity [rad] (1xN)
// mu : (optionnal) geocentric gravitational constant [m^3/s^2] (default value is %CL_mu)
// sma: semi major axis [m] (1xN)
// ecc: eccentricity (1xN)
//
// Authors
// CNES - DCT/SB
//
// Examples
// rp = 7078.e3;
// vinf = 12.e3;
// [sma,ecc] = CL_op_rpvinf2ae(rp,vinf)

// Declarations:
global %CL_mu;

// Code:

if ~exists('mu','local') then mu=%CL_mu; end

sma = mu./(vinf.^2)
ecc = rp./sma+1

endfunction
